<?php

/*
 * Used in views that display a list of questions attached to a taxonomy term
 * Assumes the tid is the first arg in the view
 *
 * The 'ask' parameter can be: 'always', 'never', or 'visible' ('visible' means all questions are currently visible in the view)
 * The 'more' parameter can be: 'always', 'never', or 'not_visible' ('not_visible' means all questions are *not* currently visible)
 *
 * Modules can define further links they would like to add using hook_answers_taxonomy_view_links($view)
 *
 * See answers_do.module for an example
 */
function answers_taxonomy_view_links($view, $ask='always', $more='always') {
  $display = $view->display[$view->current_display];
  $links = array();

  $tid = $view->args[0];
  $term= taxonomy_get_term($tid);
  $actual_count = taxonomy_term_count_nodes($tid, 'question');
  $max_count = $view->pager['items_per_page'];

  // If there are more questions, add a 'More' link
  if (($more == 'always') || (($more == 'not_visible') &&($actual_count > $max_count))) {
    $links[] = answers_taxonomy_more_link($tid);
  }
  
  // If the user has permission to create questions and the rest, provide a link to do so
  if ((user_access('create question content')) && (($ask == 'always') || (($ask='visible') && ($actual_count <= $max_count)))) {
    $links[] = answers_taxonomy_ask_new_link($term);
  }

  // Add in links from other modules
  $new_links = module_invoke_all('answers_taxonomy_view_links', $view);
  return array_merge($links, $new_links);
}

function answers_taxonomy_more_link($term) {
  $link = array(
    'title' => 'More', 
    'href' => 'questions/term/' . $term->tid,
  );
  return $link;
}

function answers_taxonomy_ask_new_link ($term) {
  $link = array(
    'title' => 'Ask New', 
    'href' => 'node/add/question',
    'query' => array('term_name' => $term->name),
  );
  return $link;
}

/**
 * Implements hook_form_FORM_ID_alter() for question_node_form().
 *
 * Looks for a "tid" argument and, if found, adds it to the new question form.
 */
function answers_taxonomy_form_question_node_form_alter(&$form, &$form_state) {
  if (isset($_GET['term_name'])) {
    $form['#after_build'][] = 'answers_taxonomy_question_node_form_after_build';
  }
}

function answers_taxonomy_question_node_form_after_build ($form, &$form_state) {
  $name = $_GET['term_name'];
  $v = answers_taxonomy_vocabulary();
  $vid = $v['vid'];
  $form['taxonomy']['tags'][$vid]['#value']=$name;
  return $form;
}

/**
 * Implements hook_nodeapi
 *
 * Adds a term to a node if one is provided in '$node->tid'
 * The 'term_name' form element in 'answers_taxonomy_form_question_form_alter()' creates a '$node->tid'
 *
 */
function answers_taxonomy_nodeapi (&$node, $op) {
  if (($node->type == 'question') && ($op == 'presave')) {
    $term = $node->tid ? taxonomy_get_term($node->tid) : NULL;
    // If we actually found a term and it is not already associated with the node ...
    if (!$node->taxonomy[$tid] && $term) {
      $node->taxonomy[] = $term;
	}
  }
}
